Class: CcipDirectoryAndConfigurationRestApiV1::ChainApiResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CcipDirectoryAndConfigurationRestApiV1::ChainApiResponse
- Defined in:
- lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb
Overview
ChainApiResponse Model.
Instance Attribute Summary collapse
-
#data ⇒ Data
Chain details grouped by chain family.
-
#ignored ⇒ Array[ChainConfigError]
List of chains that could not be configured.
-
#metadata ⇒ ChainMetadata
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(metadata:, data:, ignored:, additional_properties: nil) ⇒ ChainApiResponse
constructor
A new instance of ChainApiResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(metadata:, data:, ignored:, additional_properties: nil) ⇒ ChainApiResponse
Returns a new instance of ChainApiResponse.
43 44 45 46 47 48 49 50 51 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb', line 43 def initialize(metadata:, data:, ignored:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @metadata = @data = data @ignored = ignored @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ Data
Chain details grouped by chain family
18 19 20 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb', line 18 def data @data end |
#ignored ⇒ Array[ChainConfigError]
List of chains that could not be configured
22 23 24 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb', line 22 def ignored @ignored end |
#metadata ⇒ ChainMetadata
TODO: Write general description for this method
14 15 16 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb', line 14 def @metadata end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = ChainMetadata.from_hash(hash['metadata']) if hash['metadata'] data = Data.from_hash(hash['data']) if hash['data'] # Parameter is an array, so we need to iterate through it ignored = nil unless hash['ignored'].nil? ignored = [] hash['ignored'].each do |structure| ignored << (ChainConfigError.from_hash(structure) if structure) end end ignored = nil unless hash.key?('ignored') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ChainApiResponse.new(metadata: , data: data, ignored: ignored, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['metadata'] = 'metadata' @_hash['data'] = 'data' @_hash['ignored'] = 'ignored' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} metadata: #{@metadata.inspect}, data: #{@data.inspect}, ignored:"\ " #{@ignored.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/chain_api_response.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} metadata: #{@metadata}, data: #{@data}, ignored: #{@ignored},"\ " additional_properties: #{@additional_properties}>" end |