Class: CcipDirectoryAndConfigurationRestApiV1::LaneApiResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CcipDirectoryAndConfigurationRestApiV1::LaneApiResponse
- Defined in:
- lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb
Overview
LaneApiResponse Model.
Instance Attribute Summary collapse
-
#data ⇒ Hash[String, LaneDetails]
Lane data organized by dynamic lane keys (e.g., ‘1_to_56’, ‘ethereum-mainnet_to_polygon-mainnet’).
-
#ignored ⇒ Array[LaneConfigError]
List of lanes that could not be configured.
-
#metadata ⇒ LaneMetadata
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(metadata:, data:, ignored:, additional_properties: nil) ⇒ LaneApiResponse
constructor
A new instance of LaneApiResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(metadata:, data:, ignored:, additional_properties: nil) ⇒ LaneApiResponse
Returns a new instance of LaneApiResponse.
44 45 46 47 48 49 50 51 52 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb', line 44 def initialize(metadata:, data:, ignored:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @metadata = @data = data @ignored = ignored @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ Hash[String, LaneDetails]
Lane data organized by dynamic lane keys (e.g., ‘1_to_56’, ‘ethereum-mainnet_to_polygon-mainnet’)
19 20 21 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb', line 19 def data @data end |
#ignored ⇒ Array[LaneConfigError]
List of lanes that could not be configured
23 24 25 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb', line 23 def ignored @ignored end |
#metadata ⇒ LaneMetadata
TODO: Write general description for this method
14 15 16 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb', line 14 def @metadata end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = LaneMetadata.from_hash(hash['metadata']) if hash['metadata'] data = LaneDetails.from_hash(hash['data']) if hash['data'] data = nil unless hash.key?('data') # Parameter is an array, so we need to iterate through it ignored = nil unless hash['ignored'].nil? ignored = [] hash['ignored'].each do |structure| ignored << (LaneConfigError.from_hash(structure) if structure) end end ignored = nil unless hash.key?('ignored') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LaneApiResponse.new(metadata: , data: data, ignored: ignored, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['metadata'] = 'metadata' @_hash['data'] = 'data' @_hash['ignored'] = 'ignored' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} metadata: #{@metadata.inspect}, data: #{@data.inspect}, ignored:"\ " #{@ignored.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_api_response.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} metadata: #{@metadata}, data: #{@data}, ignored: #{@ignored},"\ " additional_properties: #{@additional_properties}>" end |