Class: CcipDirectoryAndConfigurationRestApiV1::LaneConfigError
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CcipDirectoryAndConfigurationRestApiV1::LaneConfigError
- Defined in:
- lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb
Overview
LaneConfigError Model.
Instance Attribute Summary collapse
-
#destination_chain ⇒ String
Destination chain identifier that failed configuration.
-
#missing_fields ⇒ Array[String]
List of missing or invalid configuration fields.
-
#reason ⇒ String
Human-readable reason for the configuration failure.
-
#source_chain ⇒ String
Source chain identifier that failed configuration.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(source_chain:, destination_chain:, reason:, missing_fields:, additional_properties: nil) ⇒ LaneConfigError
constructor
A new instance of LaneConfigError.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(source_chain:, destination_chain:, reason:, missing_fields:, additional_properties: nil) ⇒ LaneConfigError
Returns a new instance of LaneConfigError.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 48 def initialize(source_chain:, destination_chain:, reason:, missing_fields:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @source_chain = source_chain @destination_chain = destination_chain @reason = reason @missing_fields = missing_fields @additional_properties = additional_properties end |
Instance Attribute Details
#destination_chain ⇒ String
Destination chain identifier that failed configuration
18 19 20 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 18 def destination_chain @destination_chain end |
#missing_fields ⇒ Array[String]
List of missing or invalid configuration fields
26 27 28 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 26 def missing_fields @missing_fields end |
#reason ⇒ String
Human-readable reason for the configuration failure
22 23 24 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 22 def reason @reason end |
#source_chain ⇒ String
Source chain identifier that failed configuration
14 15 16 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 14 def source_chain @source_chain end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. source_chain = hash.key?('sourceChain') ? hash['sourceChain'] : nil destination_chain = hash.key?('destinationChain') ? hash['destinationChain'] : nil reason = hash.key?('reason') ? hash['reason'] : nil missing_fields = hash.key?('missingFields') ? hash['missingFields'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LaneConfigError.new(source_chain: source_chain, destination_chain: destination_chain, reason: reason, missing_fields: missing_fields, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['source_chain'] = 'sourceChain' @_hash['destination_chain'] = 'destinationChain' @_hash['reason'] = 'reason' @_hash['missing_fields'] = 'missingFields' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 100 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} source_chain: #{@source_chain.inspect}, destination_chain:"\ " #{@destination_chain.inspect}, reason: #{@reason.inspect}, missing_fields:"\ " #{@missing_fields.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 92 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/lane_config_error.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} source_chain: #{@source_chain}, destination_chain: #{@destination_chain},"\ " reason: #{@reason}, missing_fields: #{@missing_fields}, additional_properties:"\ " #{@additional_properties}>" end |