Class: CcipDirectoryAndConfigurationRestApiV1::OffRamp

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/ccip_directory_and_configuration_rest_api_v1/models/off_ramp.rb

Overview

OffRamp Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(address:, version:, additional_properties: nil) ⇒ OffRamp

Returns a new instance of OffRamp.



38
39
40
41
42
43
44
45
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/off_ramp.rb', line 38

def initialize(address:, version:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @address = address
  @version = version
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressString

OffRamp contract address

Returns:

  • (String)


14
15
16
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/off_ramp.rb', line 14

def address
  @address
end

#versionString

Normalized semantic version of the OffRamp contract

Returns:

  • (String)


18
19
20
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/off_ramp.rb', line 18

def version
  @version
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/off_ramp.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  address = hash.key?('address') ? hash['address'] : nil
  version = hash.key?('version') ? hash['version'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OffRamp.new(address: address,
              version: version,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/off_ramp.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['address'] = 'address'
  @_hash['version'] = 'version'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/off_ramp.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/off_ramp.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/off_ramp.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address.inspect}, version: #{@version.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
73
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/off_ramp.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address}, version: #{@version}, additional_properties:"\
  " #{@additional_properties}>"
end