Class: CcipDirectoryAndConfigurationRestApiV1::ErrorResponseException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- CcipDirectoryAndConfigurationRestApiV1::ErrorResponseException
- Defined in:
- lib/ccip_directory_and_configuration_rest_api_v1/exceptions/error_response_exception.rb
Overview
ErrorResponse class.
Instance Attribute Summary collapse
-
#error ⇒ String
Error type identifier.
-
#message ⇒ String
Human-readable error message.
-
#request_id ⇒ UUID | String
Unique identifier for the request, useful for debugging and support.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ ErrorResponseException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ ErrorResponseException
The constructor.
27 28 29 30 31 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/exceptions/error_response_exception.rb', line 27 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#error ⇒ String
Error type identifier
14 15 16 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/exceptions/error_response_exception.rb', line 14 def error @error end |
#message ⇒ String
Human-readable error message
18 19 20 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/exceptions/error_response_exception.rb', line 18 def @message end |
#request_id ⇒ UUID | String
Unique identifier for the request, useful for debugging and support
22 23 24 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/exceptions/error_response_exception.rb', line 22 def request_id @request_id end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
51 52 53 54 55 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/exceptions/error_response_exception.rb', line 51 def inspect class_name = self.class.name.split('::').last "<#{class_name} error: #{@error.inspect}, message: #{@message.inspect}, request_id:"\ " #{@request_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
45 46 47 48 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/exceptions/error_response_exception.rb', line 45 def to_s class_name = self.class.name.split('::').last "<#{class_name} error: #{@error}, message: #{@message}, request_id: #{@request_id}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
36 37 38 39 40 41 42 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/exceptions/error_response_exception.rb', line 36 def unbox(hash) return nil unless hash @error = hash.key?('error') ? hash['error'] : nil @message = hash.key?('message') ? hash['message'] : nil @request_id = hash.key?('requestId') ? hash['requestId'] : SKIP end |