Class: CcipDirectoryAndConfigurationRestApiV1::OnRamp
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CcipDirectoryAndConfigurationRestApiV1::OnRamp
- Defined in:
- lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb
Overview
OnRamp Model.
Instance Attribute Summary collapse
-
#address ⇒ String
OnRamp contract address.
-
#enforce_out_of_order ⇒ TrueClass | FalseClass
Whether the OnRamp enforces out-of-order execution.
-
#version ⇒ String
Normalized semantic version of the OnRamp contract.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(address:, version:, enforce_out_of_order: SKIP, additional_properties: nil) ⇒ OnRamp
constructor
A new instance of OnRamp.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(address:, version:, enforce_out_of_order: SKIP, additional_properties: nil) ⇒ OnRamp
Returns a new instance of OnRamp.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb', line 45 def initialize(address:, version:, enforce_out_of_order: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @address = address @version = version @enforce_out_of_order = enforce_out_of_order unless enforce_out_of_order == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address ⇒ String
OnRamp contract address
14 15 16 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb', line 14 def address @address end |
#enforce_out_of_order ⇒ TrueClass | FalseClass
Whether the OnRamp enforces out-of-order execution
22 23 24 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb', line 22 def enforce_out_of_order @enforce_out_of_order end |
#version ⇒ String
Normalized semantic version of the OnRamp contract
18 19 20 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb', line 18 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. address = hash.key?('address') ? hash['address'] : nil version = hash.key?('version') ? hash['version'] : nil enforce_out_of_order = hash.key?('enforceOutOfOrder') ? hash['enforceOutOfOrder'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OnRamp.new(address: address, version: version, enforce_out_of_order: enforce_out_of_order, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['address'] = 'address' @_hash['version'] = 'version' @_hash['enforce_out_of_order'] = 'enforceOutOfOrder' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb', line 34 def self.optionals %w[ enforce_out_of_order ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 93 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} address: #{@address.inspect}, version: #{@version.inspect},"\ " enforce_out_of_order: #{@enforce_out_of_order.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/on_ramp.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} address: #{@address}, version: #{@version}, enforce_out_of_order:"\ " #{@enforce_out_of_order}, additional_properties: #{@additional_properties}>" end |