Class: CcipDirectoryAndConfigurationRestApiV1::TokenConfigError
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CcipDirectoryAndConfigurationRestApiV1::TokenConfigError
- Defined in:
- lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb
Overview
TokenConfigError Model.
Instance Attribute Summary collapse
-
#missing_fields ⇒ Array[String]
List of missing required fields.
-
#reason ⇒ String
Reason for the configuration error.
-
#symbol ⇒ String
Token symbol.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(symbol:, reason:, missing_fields:, additional_properties: nil) ⇒ TokenConfigError
constructor
A new instance of TokenConfigError.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(symbol:, reason:, missing_fields:, additional_properties: nil) ⇒ TokenConfigError
Returns a new instance of TokenConfigError.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb', line 43 def initialize(symbol:, reason:, missing_fields:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @symbol = symbol @reason = reason @missing_fields = missing_fields @additional_properties = additional_properties end |
Instance Attribute Details
#missing_fields ⇒ Array[String]
List of missing required fields
22 23 24 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb', line 22 def missing_fields @missing_fields end |
#reason ⇒ String
Reason for the configuration error
18 19 20 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb', line 18 def reason @reason end |
#symbol ⇒ String
Token symbol
14 15 16 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb', line 14 def symbol @symbol end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. symbol = hash.key?('symbol') ? hash['symbol'] : nil reason = hash.key?('reason') ? hash['reason'] : nil missing_fields = hash.key?('missingFields') ? hash['missingFields'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TokenConfigError.new(symbol: symbol, reason: reason, missing_fields: missing_fields, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['symbol'] = 'symbol' @_hash['reason'] = 'reason' @_hash['missing_fields'] = 'missingFields' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} symbol: #{@symbol.inspect}, reason: #{@reason.inspect}, missing_fields:"\ " #{@missing_fields.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/ccip_directory_and_configuration_rest_api_v1/models/token_config_error.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} symbol: #{@symbol}, reason: #{@reason}, missing_fields: #{@missing_fields},"\ " additional_properties: #{@additional_properties}>" end |